On 01/29/2014 08:35 AM, Dominik Bernhardt wrote: > I just tested it again with the latest master from today. For my > particular project the configure step with the current master takes > 290s. If I only replace the UseQt4.cmake in the master with the > version from 2.8.12.1 the configure time goes down to 23s!! > I'm also surprised that such a tiny change results in a slowdown of > more than 1000%. But at least in my setup this is the case.
I explained here: http://www.cmake.org/pipermail/cmake-developers/2014-January/009487.html how the '$' in a value changes some core logic from a short-circuit to a complex evaluation. However, the question now is why does this one COMPILE_DEFINITIONS property value get evaluated so many times that it becomes so noticeable. How many directories (add_subdirectory) and targets (add_library or add_executable) does the project have? -Brad -- Powered by www.kitware.com Visit other Kitware open-source projects at http://www.kitware.com/opensource/opensource.html Please keep messages on-topic and check the CMake FAQ at: http://www.cmake.org/Wiki/CMake_FAQ Follow this link to subscribe/unsubscribe: http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers
